#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
utils functions related to insight
"""


def inlog(insight_id: str):
    """[summary]

    Args:
        insight_id (str): [description]

    Returns:
        [type]: [description]
    """
    return False


def ingraph(graph, action: str, action_subject: str, action_object: str):
    """[summary]

    Args:
        graph ([type]): [description]
        action (str): [description]
        action_subject (str): [description]
        action_object (str): [description]

    Returns:
        [type]: [description]
    """
    return False


def get_next_id():
    """[summary]

    Returns:
        [type]: [description]
    """
    return 0


def write_insight_log(fields: dict):
    """[summary]

    Args:
        fields (dict): [description]
    """
    pass


def read_insight_log(insight_id: str):
    """[summary]

    Args:
        insight_id (str): [description]

    Returns:
        [type]: [description]
    """
    return None


def remove_insight_log(insight_id: str):
    """[summary]

    Args:
        insight_id (str): [description]
    """
    pass


def parse_to_list(input):
    """[summary]

    Args:
        input ([type]): [description]

    Returns:
        [type]: [description]
    """
    return []


def parse_keywords(input):
    """[summary]

    Args:
        input ([type]): [description]

    Returns:
        [type]: [description]
    """
    return parse_to_list(input)


def parse_citations(input, note: str):
    """[summary]

    Args:
        input ([type]): [description]

    Returns:
        [type]: [description]
    """
    return []
